#ifndef UU_XOSHIRO_H
#define UU_XOSHIRO_H

#include "uulib/UUID.h"

void xo_srand(void);
U64  xo_rand(void);

#endif
/* ex:set ts=2 sw=2 itab=spaces: */
